package riomhaire.lti;

import lombok.AllArgsConstructor;
import org.springframework.web.servlet.ModelAndView;
import riomhaire.lti.core.model.LTIMessage;
import riomhaire.lti.core.model.interfaces.ApplicationRegistry;
import riomhaire.lti.core.model.interfaces.ClientRegistrationResolver;
import riomhaire.lti.core.model.interfaces.CommandDispatcher;

/**
 *  ApplicationRegistry is the 'environment' within which commands ... it should contain things like
 *  downstream service proxies etc.
 *
 *  The registry is also where the command dispatcher resides so that commands can call other commands.
 *
 *  The Environment os specific to the message that the command processes and the responses they generate.
 *  In this model all commands take the same message model and return the same consistent model.
 */
@AllArgsConstructor
public class Registry implements ApplicationRegistry<ModelAndView,LTIMessage> {

    // This is the command dispatcher
    private final CommandDispatcher<ModelAndView, ApplicationRegistry<ModelAndView,LTIMessage>, LTIMessage> commandDispatcher;
    // We need somewhere to read a tool/partner integration from - this service proxy performs that role.
    private final ClientRegistrationResolver clientRegistrationResolver;


    /**
     *  Return the current client configuration resolver
     * @return     ClientRegistrationResolver
     */
    @Override
    public ClientRegistrationResolver clientRegistrationResolver() {
        return clientRegistrationResolver;
    }

    /**
     * Returns access to the current command dispatcher
     *
     * @return  CommandDispatcher
     */
    @Override
    public CommandDispatcher<ModelAndView, ApplicationRegistry<ModelAndView, LTIMessage>, LTIMessage> commandDispatcher() {
        return commandDispatcher;
    }


}

